@@ -6,22 +6,13 @@ from torch.autograd import Variable
 
 
 class CorrelationCallback(Callback):
-    def on_train_epoch_end(self, trainer: Trainer, pl_module: LightningModule) -> None:
-        pl_module.log(
-            "train/corr",
-            pl_module.score(trainer.train_dataloader, train=True).sum(),
-        )
-
     def on_validation_epoch_end(
             self, trainer: Trainer, pl_module: LightningModule
     ) -> None:
-        try:
-            pl_module.log(
+        pl_module.log(
                 "val/corr",
                 pl_module.score(trainer.val_dataloaders[0]).sum(),
             )
-        except:
-            pass
 
 
 class GenerativeCallback(Callback):
