@@ -1,3 +1,4 @@
+from ._rcca import rCCA, CCA, PLS
 from ._gcca import GCCA, KGCCA
 from ._iterative import (
     PLS_ALS,
@@ -12,7 +13,7 @@ from ._iterative import (
 from ._mcca import MCCA, KCCA
 from ._ncca import NCCA
 from ._partialcca import PartialCCA
-from ._rcca import rCCA, CCA, PLS
+from ._prcca import PRCCA, GRCCA
 from ._tcca import TCCA, KTCCA
 
 __all__ = [
@@ -35,13 +36,14 @@ __all__ = [
     "PLS",
     "TCCA",
     "KTCCA",
+    "PRCCA",
+    "GRCCA"
 ]
 
 try:
     from ._stochastic import StochasticPowerPLS, IncrementalPLS
 
-    __all__.extend("StochasticPowerPLS",
-                   "IncrementalPLS")
+    __all__.extend("StochasticPowerPLS", "IncrementalPLS")
 except:
     pass
 
